@@ -50,13 +50,15 @@ crosstab <- function(df, x, y, weight, remove = "", n = TRUE, pct_type = "row",
                 n = first(total)) %>%
       # Remove values included in "remove" string
       filter(!str_to_upper({{x}}) %in% str_to_upper(remove),
-             !str_to_upper({{y}}) %in% str_to_upper(remove))
+             !str_to_upper({{y}}) %in% str_to_upper(remove)) %>%
+      ungroup()
 
     # spread if format = wide
     if(format == "wide"){
       d.output <- d.output %>%
         # Spread so x is rows and y is columns
-        pivot_wider(names_from = {{y}}, values_from = pct, values_fill = list(pct = 0)) %>%
+        pivot_wider(names_from = {{y}}, values_from = pct,
+                    values_fill = list(pct = 0), names_sort = TRUE) %>%
         # move total row to end
         select(-one_of("n"), one_of("n")) %>%
         ungroup()
@@ -91,7 +93,8 @@ crosstab <- function(df, x, y, weight, remove = "", n = TRUE, pct_type = "row",
       total.row <- d.output %>%
         group_by({{y}}, n) %>%
         summarise() %>%
-        pivot_wider(names_from = {{y}}, values_from = n, values_fill = list(pct = 0)) %>%
+        pivot_wider(names_from = {{y}}, values_from = n, values_fill = list(pct = 0),
+                    names_sort = TRUE) %>%
         mutate({{x}} := "n")
 
       # spread the output table
@@ -99,7 +102,8 @@ crosstab <- function(df, x, y, weight, remove = "", n = TRUE, pct_type = "row",
         # drop the n column
         select(-n) %>%
         # spread so x is rows and y is columns
-        pivot_wider(names_from = {{y}}, values_from = pct, values_fill = list(pct = 0))
+        pivot_wider(names_from = {{y}}, values_from = pct, values_fill = list(pct = 0),
+                    names_sort = TRUE)
 
       # if n = TRUE, then add then n row
       # this causes the response column to switch from factor to character
@@ -134,7 +138,8 @@ crosstab <- function(df, x, y, weight, remove = "", n = TRUE, pct_type = "row",
     if(format == "wide"){
       d.output <- d.output %>%
         # Spread so x is rows and y is columns
-        pivot_wider(names_from = {{y}}, values_from = pct, values_fill = list(pct = 0)) %>%
+        pivot_wider(names_from = {{y}}, values_from = pct, values_fill = 0,
+                    names_sort = TRUE) %>%
         # move total row to end
         select(-one_of("n"), one_of("n")) %>%
         ungroup()
